# py3status-omegav
py3status module for viewing the door status at Omega Verksted

Install the module

`pip install py3status-omegav`

Add the following line to your py3status config

`order += "omegav"`
